# sophiabus230

[![PyPI version](https://badge.fury.io/py/sophiabus230.svg)](https://badge.fury.io/py/sophiabus230) [![Build Status](https://travis-ci.org/paraita/sophiabus230.svg?branch=master)](https://travis-ci.org/paraita/sophiabus230) [![Coverage Status](https://coveralls.io/repos/github/paraita/sophiabus230/badge.svg?branch=master)](https://coveralls.io/github/paraita/sophiabus230?branch=master)

Module to get the timetable of the Sophia Antipolis bus line 230

# License
This software is available under the MIT license